==> openshift-model-monitoring-6.5.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/WeChatConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class WeChatConfigFluentImpl<A extends WeChatConfigFluent<A>> extends BaseFluent<A> implements WeChatConfigFluent<A>{
  public WeChatConfigFluentImpl() {
  }
  public WeChatConfigFluentImpl(WeChatConfig instance) {
    this.withAgentID(instance.getAgentID()); 
    this.withApiSecret(instance.getApiSecret()); 
    this.withApiURL(instance.getApiURL()); 
    this.withCorpID(instance.getCorpID()); 
    this.withHttpConfig(instance.getHttpConfig()); 
    this.withMessage(instance.getMessage()); 
    this.withMessageType(instance.getMessageType()); 
    this.withSendResolved(instance.getSendResolved()); 
    this.withToParty(instance.getToParty()); 
    this.withToTag(instance.getToTag()); 
    this.withToUser(instance.getToUser()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String agentID;
  private SecretKeySelector apiSecret;
  private String apiURL;
  private String corpID;
  private HTTPConfigBuilder httpConfig;
  private String message;
  private String messageType;
  private Boolean sendResolved;
  private String toParty;
  private String toTag;
  private String toUser;
  private Map<String,Object> additionalProperties;
  public String getAgentID() {
    return this.agentID;
  }
  public A withAgentID(String agentID) {
    this.agentID=agentID; return (A) this;
  }
  public Boolean hasAgentID() {
    return this.agentID != null;
  }
  public SecretKeySelector getApiSecret() {
    return this.apiSecret;
  }
  public A withApiSecret(SecretKeySelector apiSecret) {
    this.apiSecret=apiSecret; return (A) this;
  }
  public Boolean hasApiSecret() {
    return this.apiSecret != null;
  }
  public A withNewApiSecret(String key,String name,Boolean optional) {
    return (A)withApiSecret(new SecretKeySelector(key, name, optional));
  }
  public String getApiURL() {
    return this.apiURL;
  }
  public A withApiURL(String apiURL) {
    this.apiURL=apiURL; return (A) this;
  }
  public Boolean hasApiURL() {
    return this.apiURL != null;
  }
  public String getCorpID() {
    return this.corpID;
  }
  public A withCorpID(String corpID) {
    this.corpID=corpID; return (A) this;
  }
  public Boolean hasCorpID() {
    return this.corpID != null;
  }
  
  /**
   * This method has been deprecated, please use method buildHttpConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPConfig getHttpConfig() {
    return this.httpConfig!=null ?this.httpConfig.build():null;
  }
  public HTTPConfig buildHttpConfig() {
    return this.httpConfig!=null ?this.httpConfig.build():null;
  }
  public A withHttpConfig(HTTPConfig httpConfig) {
    _visitables.get("httpConfig").remove(this.httpConfig);
    if (httpConfig!=null){ this.httpConfig= new HTTPConfigBuilder(httpConfig); _visitables.get("httpConfig").add(this.httpConfig);} else { this.httpConfig = null; _visitables.get("httpConfig").remove(this.httpConfig); } return (A) this;
  }
  public Boolean hasHttpConfig() {
    return this.httpConfig != null;
  }
  public WeChatConfigFluent.HttpConfigNested<A> withNewHttpConfig() {
    return new WeChatConfigFluentImpl.HttpConfigNestedImpl();
  }
  public WeChatConfigFluent.HttpConfigNested<A> withNewHttpConfigLike(HTTPConfig item) {
    return new WeChatConfigFluentImpl.HttpConfigNestedImpl(item);
  }
  public WeChatConfigFluent.HttpConfigNested<A> editHttpConfig() {
    return withNewHttpConfigLike(getHttpConfig());
  }
  public WeChatConfigFluent.HttpConfigNested<A> editOrNewHttpConfig() {
    return withNewHttpConfigLike(getHttpConfig() != null ? getHttpConfig(): new HTTPConfigBuilder().build());
  }
  public WeChatConfigFluent.HttpConfigNested<A> editOrNewHttpConfigLike(HTTPConfig item) {
    return withNewHttpConfigLike(getHttpConfig() != null ? getHttpConfig(): item);
  }
  public String getMessage() {
    return this.message;
  }
  public A withMessage(String message) {
    this.message=message; return (A) this;
  }
  public Boolean hasMessage() {
    return this.message != null;
  }
  public String getMessageType() {
    return this.messageType;
  }
  public A withMessageType(String messageType) {
    this.messageType=messageType; return (A) this;
  }
  public Boolean hasMessageType() {
    return this.messageType != null;
  }
  public Boolean getSendResolved() {
    return this.sendResolved;
  }
  public A withSendResolved(Boolean sendResolved) {
    this.sendResolved=sendResolved; return (A) this;
  }
  public Boolean hasSendResolved() {
    return this.sendResolved != null;
  }
  public String getToParty() {
    return this.toParty;
  }
  public A withToParty(String toParty) {
    this.toParty=toParty; return (A) this;
  }
  public Boolean hasToParty() {
    return this.toParty != null;
  }
  public String getToTag() {
    return this.toTag;
  }
  public A withToTag(String toTag) {
    this.toTag=toTag; return (A) this;
  }
  public Boolean hasToTag() {
    return this.toTag != null;
  }
  public String getToUser() {
    return this.toUser;
  }
  public A withToUser(String toUser) {
    this.toUser=toUser; return (A) this;
  }
  public Boolean hasToUser() {
    return this.toUser != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    WeChatConfigFluentImpl that = (WeChatConfigFluentImpl) o;
    if (agentID != null ? !agentID.equals(that.agentID) :that.agentID != null) return false;
    if (apiSecret != null ? !apiSecret.equals(that.apiSecret) :that.apiSecret != null) return false;
    if (apiURL != null ? !apiURL.equals(that.apiURL) :that.apiURL != null) return false;
    if (corpID != null ? !corpID.equals(that.corpID) :that.corpID != null) return false;
    if (httpConfig != null ? !httpConfig.equals(that.httpConfig) :that.httpConfig != null) return false;
    if (message != null ? !message.equals(that.message) :that.message != null) return false;
    if (messageType != null ? !messageType.equals(that.messageType) :that.messageType != null) return false;
    if (sendResolved != null ? !sendResolved.equals(that.sendResolved) :that.sendResolved != null) return false;
    if (toParty != null ? !toParty.equals(that.toParty) :that.toParty != null) return false;
    if (toTag != null ? !toTag.equals(that.toTag) :that.toTag != null) return false;
    if (toUser != null ? !toUser.equals(that.toUser) :that.toUser != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(agentID,  apiSecret,  apiURL,  corpID,  httpConfig,  message,  messageType,  sendResolved,  toParty,  toTag,  toUser,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (agentID != null) { sb.append("agentID:"); sb.append(agentID + ","); }
    if (apiSecret != null) { sb.append("apiSecret:"); sb.append(apiSecret + ","); }
    if (apiURL != null) { sb.append("apiURL:"); sb.append(apiURL + ","); }
    if (corpID != null) { sb.append("corpID:"); sb.append(corpID + ","); }
    if (httpConfig != null) { sb.append("httpConfig:"); sb.append(httpConfig + ","); }
    if (message != null) { sb.append("message:"); sb.append(message + ","); }
    if (messageType != null) { sb.append("messageType:"); sb.append(messageType + ","); }
    if (sendResolved != null) { sb.append("sendResolved:"); sb.append(sendResolved + ","); }
    if (toParty != null) { sb.append("toParty:"); sb.append(toParty + ","); }
    if (toTag != null) { sb.append("toTag:"); sb.append(toTag + ","); }
    if (toUser != null) { sb.append("toUser:"); sb.append(toUser + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withSendResolved() {
    return withSendResolved(true);
  }
  class HttpConfigNestedImpl<N> extends HTTPConfigFluentImpl<WeChatConfigFluent.HttpConfigNested<N>> implements WeChatConfigFluent.HttpConfigNested<N>,Nested<N>{
    HttpConfigNestedImpl(HTTPConfig item) {
      this.builder = new HTTPConfigBuilder(this, item);
    }
    HttpConfigNestedImpl() {
      this.builder = new HTTPConfigBuilder(this);
    }
    HTTPConfigBuilder builder;
    public N and() {
      return (N) WeChatConfigFluentImpl.this.withHttpConfig(builder.build());
    }
    public N endHttpConfig() {
      return and();
    }
    
  }
  
}

==> openshift-model-monitoring-6.7.2-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/WeChatConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class WeChatConfigFluentImpl<A extends WeChatConfigFluent<A>> extends BaseFluent<A> implements WeChatConfigFluent<A>{
  public WeChatConfigFluentImpl() {
  }
  public WeChatConfigFluentImpl(WeChatConfig instance) {
    if (instance != null) {
      this.withAgentID(instance.getAgentID());
      this.withApiSecret(instance.getApiSecret());
      this.withApiURL(instance.getApiURL());
      this.withCorpID(instance.getCorpID());
      this.withHttpConfig(instance.getHttpConfig());
      this.withMessage(instance.getMessage());
      this.withMessageType(instance.getMessageType());
      this.withSendResolved(instance.getSendResolved());
      this.withToParty(instance.getToParty());
      this.withToTag(instance.getToTag());
      this.withToUser(instance.getToUser());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String agentID;
  private SecretKeySelector apiSecret;
  private String apiURL;
  private String corpID;
  private HTTPConfigBuilder httpConfig;
  private String message;
  private String messageType;
  private Boolean sendResolved;
  private String toParty;
  private String toTag;
  private String toUser;
  private Map<String,Object> additionalProperties;
  public String getAgentID() {
    return this.agentID;
  }
  public A withAgentID(String agentID) {
    this.agentID=agentID; return (A) this;
  }
  public Boolean hasAgentID() {
    return this.agentID != null;
  }
  public SecretKeySelector getApiSecret() {
    return this.apiSecret;
  }
  public A withApiSecret(SecretKeySelector apiSecret) {
    this.apiSecret=apiSecret; return (A) this;
  }
  public Boolean hasApiSecret() {
    return this.apiSecret != null;
  }
  public A withNewApiSecret(String key,String name,Boolean optional) {
    return (A)withApiSecret(new SecretKeySelector(key, name, optional));
  }
  public String getApiURL() {
    return this.apiURL;
  }
  public A withApiURL(String apiURL) {
    this.apiURL=apiURL; return (A) this;
  }
  public Boolean hasApiURL() {
    return this.apiURL != null;
  }
  public String getCorpID() {
    return this.corpID;
  }
  public A withCorpID(String corpID) {
    this.corpID=corpID; return (A) this;
  }
  public Boolean hasCorpID() {
    return this.corpID != null;
  }
  
  /**
   * This method has been deprecated, please use method buildHttpConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPConfig getHttpConfig() {
    return this.httpConfig!=null ?this.httpConfig.build():null;
  }
  public HTTPConfig buildHttpConfig() {
    return this.httpConfig!=null ?this.httpConfig.build():null;
  }
  public A withHttpConfig(HTTPConfig httpConfig) {
    _visitables.get("httpConfig").remove(this.httpConfig);
    if (httpConfig!=null){ this.httpConfig= new HTTPConfigBuilder(httpConfig); _visitables.get("httpConfig").add(this.httpConfig);} else { this.httpConfig = null; _visitables.get("httpConfig").remove(this.httpConfig); } return (A) this;
  }
  public Boolean hasHttpConfig() {
    return this.httpConfig != null;
  }
  public WeChatConfigFluentImpl.HttpConfigNested<A> withNewHttpConfig() {
    return new WeChatConfigFluentImpl.HttpConfigNestedImpl();
  }
  public WeChatConfigFluentImpl.HttpConfigNested<A> withNewHttpConfigLike(HTTPConfig item) {
    return new WeChatConfigFluentImpl.HttpConfigNestedImpl(item);
  }
  public WeChatConfigFluentImpl.HttpConfigNested<A> editHttpConfig() {
    return withNewHttpConfigLike(getHttpConfig());
  }
  public WeChatConfigFluentImpl.HttpConfigNested<A> editOrNewHttpConfig() {
    return withNewHttpConfigLike(getHttpConfig() != null ? getHttpConfig(): new HTTPConfigBuilder().build());
  }
  public WeChatConfigFluentImpl.HttpConfigNested<A> editOrNewHttpConfigLike(HTTPConfig item) {
    return withNewHttpConfigLike(getHttpConfig() != null ? getHttpConfig(): item);
  }
  public String getMessage() {
    return this.message;
  }
  public A withMessage(String message) {
    this.message=message; return (A) this;
  }
  public Boolean hasMessage() {
    return this.message != null;
  }
  public String getMessageType() {
    return this.messageType;
  }
  public A withMessageType(String messageType) {
    this.messageType=messageType; return (A) this;
  }
  public Boolean hasMessageType() {
    return this.messageType != null;
  }
  public Boolean getSendResolved() {
    return this.sendResolved;
  }
  public A withSendResolved(Boolean sendResolved) {
    this.sendResolved=sendResolved; return (A) this;
  }
  public Boolean hasSendResolved() {
    return this.sendResolved != null;
  }
  public String getToParty() {
    return this.toParty;
  }
  public A withToParty(String toParty) {
    this.toParty=toParty; return (A) this;
  }
  public Boolean hasToParty() {
    return this.toParty != null;
  }
  public String getToTag() {
    return this.toTag;
  }
  public A withToTag(String toTag) {
    this.toTag=toTag; return (A) this;
  }
  public Boolean hasToTag() {
    return this.toTag != null;
  }
  public String getToUser() {
    return this.toUser;
  }
  public A withToUser(String toUser) {
    this.toUser=toUser; return (A) this;
  }
  public Boolean hasToUser() {
    return this.toUser != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    WeChatConfigFluentImpl that = (WeChatConfigFluentImpl) o;
    if (!java.util.Objects.equals(agentID, that.agentID)) return false;

    if (!java.util.Objects.equals(apiSecret, that.apiSecret)) return false;

    if (!java.util.Objects.equals(apiURL, that.apiURL)) return false;

    if (!java.util.Objects.equals(corpID, that.corpID)) return false;

    if (!java.util.Objects.equals(httpConfig, that.httpConfig)) return false;

    if (!java.util.Objects.equals(message, that.message)) return false;

    if (!java.util.Objects.equals(messageType, that.messageType)) return false;

    if (!java.util.Objects.equals(sendResolved, that.sendResolved)) return false;

    if (!java.util.Objects.equals(toParty, that.toParty)) return false;

    if (!java.util.Objects.equals(toTag, that.toTag)) return false;

    if (!java.util.Objects.equals(toUser, that.toUser)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(agentID,  apiSecret,  apiURL,  corpID,  httpConfig,  message,  messageType,  sendResolved,  toParty,  toTag,  toUser,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (agentID != null) { sb.append("agentID:"); sb.append(agentID + ","); }
    if (apiSecret != null) { sb.append("apiSecret:"); sb.append(apiSecret + ","); }
    if (apiURL != null) { sb.append("apiURL:"); sb.append(apiURL + ","); }
    if (corpID != null) { sb.append("corpID:"); sb.append(corpID + ","); }
    if (httpConfig != null) { sb.append("httpConfig:"); sb.append(httpConfig + ","); }
    if (message != null) { sb.append("message:"); sb.append(message + ","); }
    if (messageType != null) { sb.append("messageType:"); sb.append(messageType + ","); }
    if (sendResolved != null) { sb.append("sendResolved:"); sb.append(sendResolved + ","); }
    if (toParty != null) { sb.append("toParty:"); sb.append(toParty + ","); }
    if (toTag != null) { sb.append("toTag:"); sb.append(toTag + ","); }
    if (toUser != null) { sb.append("toUser:"); sb.append(toUser + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withSendResolved() {
    return withSendResolved(true);
  }
  class HttpConfigNestedImpl<N> extends HTTPConfigFluentImpl<WeChatConfigFluentImpl.HttpConfigNested<N>> implements WeChatConfigFluentImpl.HttpConfigNested<N>,Nested<N>{
    HttpConfigNestedImpl(HTTPConfig item) {
      this.builder = new HTTPConfigBuilder(this, item);
    }
    HttpConfigNestedImpl() {
      this.builder = new HTTPConfigBuilder(this);
    }
    HTTPConfigBuilder builder;
    public N and() {
      return (N) WeChatConfigFluentImpl.this.withHttpConfig(builder.build());
    }
    public N endHttpConfig() {
      return and();
    }
    
  }
  
}
